@@ -17,31 +17,27 @@
  * Authors: Benjamin Otte <otte@gnome.org>
  */
 
-#ifndef __GDK_SNAPSHOT_H__
-#define __GDK_SNAPSHOT_H__
+#pragma once
 
 #if !defined (__GDK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gdk/gdk.h> can be included directly."
 #endif
 
 #include <gdk/gdktypes.h>
-#include <gdk/gdkversionmacros.h>
 
 G_BEGIN_DECLS
 
-typedef struct _GdkSnapshotClass       GdkSnapshotClass;
+typedef struct _GdkSnapshotClass        GdkSnapshotClass;
 
 #define GDK_TYPE_SNAPSHOT               (gdk_snapshot_get_type ())
 
 #define GDK_SNAPSHOT(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GDK_TYPE_SNAPSHOT, GdkSnapshot))
 #define GDK_IS_SNAPSHOT(obj)            (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GDK_TYPE_SNAPSHOT))
 
-G_DEFINE_AUTOPTR_CLEANUP_FUNC(GdkSnapshot, g_object_unref)
-
 GDK_AVAILABLE_IN_ALL
 GType           gdk_snapshot_get_type   (void) G_GNUC_CONST;
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GdkSnapshot, g_object_unref)
 
 G_END_DECLS
 
-#endif /* __GDK_SNAPSHOT_H__ */
