@@ -23,20 +23,16 @@
 
 #include <gdk/gdk.h>
 #include <gtk/gtkenums.h>
+#include <gtk/gtkiconpaintable.h>
 
 G_BEGIN_DECLS
 
-#define GTK_TYPE_ICON_PAINTABLE    (gtk_icon_paintable_get_type ())
-#define GTK_ICON_PAINTABLE(obj)    (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_ICON_PAINTABLE, GtkIconPaintable))
-#define GTK_IS_ICON_PAINTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_ICON_PAINTABLE))
+typedef struct _GtkIconTheme      GtkIconTheme;
 
 #define GTK_TYPE_ICON_THEME        (gtk_icon_theme_get_type ())
 #define GTK_ICON_THEME(obj)        (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_ICON_THEME, GtkIconTheme))
 #define GTK_IS_ICON_THEME(obj)     (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_ICON_THEME))
 
-typedef struct _GtkIconPaintable  GtkIconPaintable;
-typedef struct _GtkIconTheme      GtkIconTheme;
-
 /**
  * GtkIconLookupFlags:
  * @GTK_ICON_LOOKUP_FORCE_REGULAR: Try to always load regular icons, even
@@ -145,23 +141,8 @@ GtkIconPaintable *gtk_icon_theme_lookup_by_gicon     (GtkIconTheme
                                                       GtkTextDirection             direction,
                                                       GtkIconLookupFlags           flags);
 GDK_AVAILABLE_IN_ALL
-GtkIconPaintable *gtk_icon_paintable_new_for_file    (GFile                       *file,
-                                                      int                          size,
-                                                      int                          scale);
-GDK_AVAILABLE_IN_ALL
 char **               gtk_icon_theme_get_icon_names  (GtkIconTheme                *self);
 
-GDK_AVAILABLE_IN_ALL
-GType                 gtk_icon_paintable_get_type         (void) G_GNUC_CONST;
-
-GDK_AVAILABLE_IN_ALL
-GFile *               gtk_icon_paintable_get_file          (GtkIconPaintable  *self);
-GDK_AVAILABLE_IN_ALL
-const char *         gtk_icon_paintable_get_icon_name     (GtkIconPaintable  *self);
-GDK_AVAILABLE_IN_ALL
-gboolean              gtk_icon_paintable_is_symbolic       (GtkIconPaintable  *self);
-
-G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkIconPaintable, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkIconTheme, g_object_unref)
 
 G_END_DECLS
