@@ -19,8 +19,7 @@
  *
  */
 
-#ifndef __GTK_LIST_BOX_H__
-#define __GTK_LIST_BOX_H__
+#pragma once
 
 #if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
@@ -91,7 +90,7 @@ typedef gboolean (*GtkListBoxFilterFunc) (GtkListBoxRow *row,
  * Compare two rows to determine which should be first.
  *
  * Returns: < 0 if @row1 should be before @row2, 0 if they are
- *     equal and > 0 otherwise
+ *   equal and > 0 otherwise
  */
 typedef int (*GtkListBoxSortFunc) (GtkListBoxRow *row1,
                                    GtkListBoxRow *row2,
@@ -100,7 +99,7 @@ typedef int (*GtkListBoxSortFunc) (GtkListBoxRow *row1,
 /**
  * GtkListBoxUpdateHeaderFunc:
  * @row: the row to update
- * @before: (allow-none): the row before @row, or %NULL if it is first
+ * @before: (nullable): the row before @row, or %NULL if it is first
  * @user_data: (closure): user data
  *
  * Whenever @row changes or which row is before @row changes this
@@ -121,6 +120,9 @@ typedef void (*GtkListBoxUpdateHeaderFunc) (GtkListBoxRow *row,
  * Called for list boxes that are bound to a `GListModel` with
  * gtk_list_box_bind_model() for each item that gets added to the model.
  *
+ * If the widget returned is not a #GtkListBoxRow widget, then the widget
+ * will be inserted as the child of an intermediate #GtkListBoxRow.
+ *
  * Returns: (transfer full): a `GtkWidget` that represents @item
  */
 typedef GtkWidget * (*GtkListBoxCreateWidgetFunc) (gpointer item,
@@ -178,6 +180,9 @@ void           gtk_list_box_insert                       (GtkListBox
 GDK_AVAILABLE_IN_ALL
 void           gtk_list_box_remove                       (GtkListBox                    *box,
                                                           GtkWidget                     *child);
+GDK_AVAILABLE_IN_4_12
+void           gtk_list_box_remove_all                   (GtkListBox                    *box);
+
 GDK_AVAILABLE_IN_ALL
 GtkListBoxRow* gtk_list_box_get_selected_row             (GtkListBox                    *box);
 GDK_AVAILABLE_IN_ALL
@@ -269,9 +274,14 @@ void           gtk_list_box_set_show_separators          (GtkListBox
 GDK_AVAILABLE_IN_ALL
 gboolean       gtk_list_box_get_show_separators          (GtkListBox                   *box);
 
+GDK_AVAILABLE_IN_4_18
+void               gtk_list_box_set_tab_behavior (GtkListBox         *box,
+                                                  GtkListTabBehavior  behavior);
+GDK_AVAILABLE_IN_4_18
+GtkListTabBehavior gtk_list_box_get_tab_behavior (GtkListBox         *box);
+
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkListBox, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkListBoxRow, g_object_unref)
 
 G_END_DECLS
 
-#endif
