@@ -18,14 +18,13 @@
  * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GTK_OVERLAY_H__
-#define __GTK_OVERLAY_H__
+#pragma once
 
 #if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
-#include <gtk/gtkbin.h>
+#include <gtk/gtkwidget.h>
 
 G_BEGIN_DECLS
 
@@ -42,13 +41,23 @@ GtkWidget *gtk_overlay_new         (void);
 GDK_AVAILABLE_IN_ALL
 void       gtk_overlay_add_overlay (GtkOverlay *overlay,
                                     GtkWidget  *widget);
+GDK_AVAILABLE_IN_ALL
+void       gtk_overlay_remove_overlay (GtkOverlay *overlay,
+                                       GtkWidget  *widget);
+
+GDK_AVAILABLE_IN_ALL
+void                  gtk_overlay_set_child (GtkOverlay *overlay,
+                                             GtkWidget  *child);
+GDK_AVAILABLE_IN_ALL
+GtkWidget *           gtk_overlay_get_child (GtkOverlay *overlay);
+
 GDK_AVAILABLE_IN_ALL
 gboolean   gtk_overlay_get_measure_overlay (GtkOverlay *overlay,
-					    GtkWidget  *widget);
+                                            GtkWidget  *widget);
 GDK_AVAILABLE_IN_ALL
 void       gtk_overlay_set_measure_overlay (GtkOverlay *overlay,
-					    GtkWidget  *widget,
-					    gboolean    measure);
+                                            GtkWidget  *widget,
+                                            gboolean    measure);
 GDK_AVAILABLE_IN_ALL
 gboolean   gtk_overlay_get_clip_overlay    (GtkOverlay *overlay,
                                             GtkWidget  *widget);
@@ -57,6 +66,7 @@ void       gtk_overlay_set_clip_overlay    (GtkOverlay *overlay,
                                             GtkWidget  *widget,
                                             gboolean    clip_overlay);
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkOverlay, g_object_unref)
+
 G_END_DECLS
 
-#endif /* __GTK_OVERLAY_H__ */
